@@ -65,7 +65,7 @@ package  Algorithm::Evolutionary::Op::Permutation;
 
 use lib qw( ../../.. );
 
-our ($VERSION) = ( '$Revision: 3.4 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 3.5 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 use Clone qw(clone);
@@ -135,11 +135,30 @@ sub apply ($;$) {
   croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
   my @arr = split("",$victim->{_str});
   my $p = new Algorithm::Permute( \@arr );
-  my $iterations = rand($self->{'_max_iterations'});
+  my $iterations = 1+rand($self->{'_max_iterations'}-1);
   for (1..$iterations) {
-    $p->next;
+    @arr = $p->next;
   }
-  $victim->{'_str'} = join( "",$p->next );
+  if ( !@arr) {
+    croak "I broke \@arr $iterations ", $self->{'_max_iterations'}, " ", $victim->{'_str'},  "\n";
+  }
+  if ( join( "", @arr ) eq $arg->{'_str'} ) {
+    # Check for all equal
+    my %letters;
+    map( $letters{$_}=1, @arr );
+    if ( scalar keys %letters  > 1) {
+      $p->reset; # We are looking for anything different, after all
+      do {
+	@arr = $p->next;
+      } until ( join( "", @arr ) ne $arg->{'_str'} );
+#      print "Vaya tela $iterations ", $self->{'_max_iterations'}, " ", $victim->{'_str'},  "\n";
+ #     print $victim->{'_str'}, "\n";
+    }
+  }
+  if ( !@arr) {
+    croak "Gosh $iterations ", $self->{'_max_iterations'}, " ", $victim->{'_str'},  "\n";
+  }
+  $victim->{'_str'} = join( "", @arr );
   return $victim;
 }
 
@@ -154,10 +173,10 @@ Uses L<Algorithm::Permute>, which is purported to be the fastest
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/13 17:50:08 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Permutation.pm,v 3.4 2011/02/13 17:50:08 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/19 17:59:32 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Permutation.pm,v 3.5 2011/02/19 17:59:32 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.4 $
+  $Revision: 3.5 $
 
 =cut
 
