@@ -22,7 +22,8 @@ L<Algorithm::Evolutionary::Op::Selector>
 
 One of the possible selectors used for selecting the pool of individuals
 that are going to be the parents of the following generation. Takes a
-set of individuals randomly out of the population, and select  the best. 
+set of individuals randomly out of the population, and select a few of 
+the best.
 
 =head1 METHODS
 
@@ -30,10 +31,9 @@ set of individuals randomly out of the population, and select  the best.
 
 
 package Algorithm::Evolutionary::Op::Tournament_Selection;
-
 use Carp;
 
-our $VERSION = '1.5';
+our ($VERSION) = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -53,10 +53,8 @@ sub new {
 
 =head2 apply( $ref_to_population[, $output_size || @$ref_to_population] )
 
-Applies the tournament selection to a population, returning another of
-the same size by default or whatever size is selected. Please bear in
-mind that, unlike other selectors, this one uses a reference to
-population instead of a population array. 
+Applies the tournament selection to a population, returning
+another of the same size by default or whatever size is selected
 
 =cut
 
@@ -67,15 +65,13 @@ sub apply ($$) {
   my @output;
   for ( my $i = 0; $i < $output_size; $i++ ) {
     #Randomly select a few guys
-    my $best = $pop->[ rand( @$pop ) ];
-    for ( my $j = 1; $j < $self->{'_tournament_size'}; $j++ ) {
-      my $this_one = $pop->[ rand( @$pop ) ];
-      if ( $this_one->{'_fitness'} > $best->{'_fitness'} ) {
-	$best = $this_one;
-      }
+    my @tournament;
+    for ( my $j = 0; $j < $self->{'_tournament_size'}; $j++ ) {
+      push( @tournament, $pop->[ rand( @$pop ) ]);
     }
     #Sort by fitness
-    push @output, $best;
+    my @sortedT = sort { $b->Fitness() <=> $a->Fitness(); } @tournament;
+    push @output, $sortedT[0];
   }
   return @output;
 }
@@ -90,6 +86,10 @@ selecting a pool of individuals
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2011/02/22 06:58:15 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Tournament_Selection.pm,v 1.2 2011/02/22 06:58:15 jmerelo Exp $ 
+  $Author: jmerelo $ 
+
 =cut
 
 "The truth is in here";
