@@ -42,7 +42,7 @@ package Algorithm::Evolutionary::Op::Uniform_Crossover_Diff;
 
 use lib qw( ../../.. );
 
-our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.6 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.5 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
 
 use Carp;
 
@@ -81,8 +81,7 @@ sure that what is interchanged is different.
 sub  apply ($$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-  my $arg2 =   shift || croak "No victim here!";
-  my $victim2 = $arg2->clone();
+  my $victim2 = shift || croak "No victim here!";
   my $victim = $arg->clone();
   my $min_length = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
@@ -111,10 +110,10 @@ sub  apply ($$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/07/08 10:38:52 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Uniform_Crossover_Diff.pm,v 3.6 2012/07/08 10:38:52 jmerelo Exp $ 
+  CVS Info: $Date: 2011/08/12 09:08:47 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Uniform_Crossover_Diff.pm,v 3.5 2011/08/12 09:08:47 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.6 $
+  $Revision: 3.5 $
   $Name $
 
 =cut
